@@ -48,7 +48,7 @@ def get_brightness_line():
 def extract_brightness(line):
     # sample: b'\tBrightness: 0.50\n'
     pattern = r".* (\d\.\d)"
-    match = search(pattern, output)
+    match = search(pattern, line)
     val = round(float(match.group(1)), 1)    
 
 ##########################
